GraphNodeConstructor

Struct GraphNodeConstructor 

pub struct GraphNodeConstructor<Node, Ctx> {
    pub default: Constructor<Node>,
    pub variants: Vec<Variant<Node, Ctx>>,
    pub group: &'static str,
    pub assembly_name: &'static str,
}
Node constructor creates scene nodes in various states.

Fields

default: Constructor<Node>

A boxed type constructor that returns a node in default state. This constructor is used at deserialization stage.

variants: Vec<Variant<Node, Ctx>>

A set of node constructors that returns specific variants of the same node type. Could be used to pre-define specific variations of nodes, for example a Mesh node could have different surfaces (sphere, cube, cone, etc.). It is used by the editor, this collection must have at least one item to be shown in the editor.

group: &'static str

Name of the group the type belongs to.

assembly_name: &'static str

A name of the assembly this node constructor is from.

Implementations

Source

impl<Node, Ctx> GraphNodeConstructor<Node, Ctx>

pub fn new<Inner>() -> Self
where Node: From<Inner>, Inner: ConstructorProvider<Node, Ctx>,

Creates a new node constructor with default values for the given scene node type. This method automatically creates default constructor, but leaves potential variants empty (nothing will be shown in the editor, use Self::with_variant to add potential variant of the constructor).

pub fn with_group(self, group: &'static str) -> Self

Sets a desired group for the constructor.

pub fn with_variant<F>(self, name: impl AsRef<str>, variant: F) -> Self
where F: Fn(&mut Ctx) -> VariantResult<Node> + Send + Sync + 'static,

Adds a new constructor variant.